@@ -1,10 +1,10 @@
 from importlib import import_module, invalidate_caches as importlib_invalidate_caches
+from logging import basicConfig, INFO
 from pkgutil import walk_packages
 
+from rich.logging import RichHandler
 from typer import Typer
 
-from deckz.utils import setup_logging
-
 
 app = Typer(
     help="Tool to handle a large number of beamer decks, "
@@ -14,7 +14,12 @@ app = Typer(
 
 
 def main() -> None:
-    setup_logging()
+    basicConfig(
+        level=INFO,
+        format="%(message)s",
+        datefmt="%H:%M:%S",
+        handlers=[RichHandler(rich_tracebacks=True)],
+    )
     _import_module_and_submodules(__name__)
     app()
 
@@ -30,7 +35,11 @@ def _import_module_and_submodules(package_name: str) -> None:
     path_string = "" if not path else path[0]
 
     for module_finder, name, _ in walk_packages(path):
-        if path_string and module_finder.path != path_string:
+        if (
+            path_string
+            and hasattr(module_finder, "path")
+            and module_finder.path != path_string  # type: ignore
+        ):
             continue
         subpackage = f"{package_name}.{name}"
         _import_module_and_submodules(subpackage)
